@@ -46,6 +46,12 @@ class vfsStreamWrapper
      * file mode: read and write
      */
     const ALL                    = 2;
+    /**
+     * The current context or null if none passed.
+     *
+     * @var resource|null
+     */
+    public $context;
     /**
      * switch whether class has already been registered as stream wrapper or not
      *
